pub struct Hijri<S>(pub S);Expand description
The Hijri Calendar
There are many variants of this calendar, using different lunar observations or calculations
(see Rules). Currently, Rules is an unstable trait, but some of its implementors
are stable, and can be constructed via the various Hijri::new_* constructors. Please comment
on this issue
if you would like to see this the ability to implement custom Rules stabilized.
This implementation supports only variants where months are either 29 or 30 days.
This corresponds to various "islamic-*" CLDR calendars,
see the individual implementors of Rules (TabularAlgorithm, UmmAlQura, AstronomicalSimulation) for more information.
Era codes
This calendar uses two era codes: ah, and bh, corresponding to the Anno Hegirae and Before Hijrah eras
Months and days
The 12 months are called al-Muḥarram (M01), Ṣafar (M02), Rabīʿ al-ʾAwwal (M03),
Rabīʿ ath-Thānī or Rabīʿ al-ʾĀkhir (M04), Jumādā al-ʾŪlā (M05), Jumādā ath-Thāniyah
or Jumādā al-ʾĀkhirah (M06), Rajab (M07), Shaʿbān (M08), Ramaḍān (M09), Shawwāl (M10),
Ḏū al-Qaʿdah (M11), Ḏū al-Ḥijjah (M12).
As a true lunar calendar, the lengths of the months depend on the lunar cycle (a month starts on the day where the waxing crescent is first observed), and will be either 29 or 30 days.
The lengths of the months are determined by the concrete Rules implementation.
There are either 6 or 7 30-day months, so the length of the year is 354 or 355 days.
Calendar drift
As a lunar calendar, this calendar does not intend to follow the solar year, and drifts more than 10 days per year with respect to the seasons.
Tuple Fields
0: SImplementations
Sourceimpl Hijri<AstronomicalSimulation>
impl Hijri<AstronomicalSimulation>
Sourcepub const fn new_simulated_mecca() -> Self
pub const fn new_simulated_mecca() -> Self
Creates a Hijri calendar using simulated sightings at Mecca.
These simulations are unofficial and are known to not necessarily match sightings
on the ground. Unless you know otherwise for sure, instead of this variant, use
Hijri::new_umm_al_qura, which uses the results of KACST’s Mecca-based calculations.
Sourcepub fn try_new_mecca_unstable<D: ?Sized>(
_provider: &D,
) -> Result<Self, DataError>
👎Deprecated since 2.1.0: use Hijri::new_simulated_mecca
pub fn try_new_mecca_unstable<D: ?Sized>( _provider: &D, ) -> Result<Self, DataError>
use Hijri::new_simulated_mecca
A version of Self::new_mecca that uses custom data provided by a DataProvider.
Sourcepub const fn new_mecca_always_calculating() -> Self
👎Deprecated since 2.1.0: use Hijri::new_simulated_mecca
pub const fn new_mecca_always_calculating() -> Self
use Hijri::new_simulated_mecca
Sourceimpl Hijri<UmmAlQura>
impl Hijri<UmmAlQura>
Sourcepub const fn new_umm_al_qura() -> Self
pub const fn new_umm_al_qura() -> Self
Sourceimpl Hijri<TabularAlgorithm>
impl Hijri<TabularAlgorithm>
Sourcepub const fn new(
leap_years: TabularAlgorithmLeapYears,
epoch: TabularAlgorithmEpoch,
) -> Self
👎Deprecated since 2.1.0: use Hijri::new_tabular
pub const fn new( leap_years: TabularAlgorithmLeapYears, epoch: TabularAlgorithmEpoch, ) -> Self
use Hijri::new_tabular
Sourcepub const fn new_tabular(
leap_years: TabularAlgorithmLeapYears,
epoch: TabularAlgorithmEpoch,
) -> Self
pub const fn new_tabular( leap_years: TabularAlgorithmLeapYears, epoch: TabularAlgorithmEpoch, ) -> Self
Creates a Hijri calendar with tabular rules and the given leap year rule and epoch.