pub struct Indian;Expand description
The Indian National (Śaka) Calendar
The Indian National calendar is a solar calendar created by the Indian government.
This implementation extends proleptically for dates before the calendar’s creation in 1879 Śaka (1957 CE).
This corresponds to the "indian" CLDR calendar.
Era codes
This calendar uses a single era code: shaka, with Śaka 0 being 78 CE. Dates before this era use negative years.
Months and days
The 12 months are called Chaitra (M01, 30 days), Vaisakha (M02, 31 days),
Jyaishtha (M03, 31 days), Ashadha (M04, 31 days), Sravana (M05, 31 days),
Bhadra (M06, 31 days), Asvina (M07, 30 days), Kartika (M08, 30 days),
Agrahayana or Margasirsha (M09, 30 days), Pausha (M10, 30 days), Magha (M11, 30 days),
Phalguna (M12, 30 days).
In leap years (years where the concurrent Gregorian year (year + 78) is leap),
Chaitra gains a 31st day.
Standard years thus have 365 days, and leap years 366.
Calendar drift
The Indian calendar has the same year lengths and leap year rules as the Gregorian calendar, so it experiences the same drift of 1 day in ~7700 years with respect to the seasons.
Implementations